# lscealice

LSCE ALICE is a python tkinter interface to align ice core data series.

_this doc file is under construction 👷‍♀️_

## Installation

Depending on your workflow, you can either 

- Install it using [pipx](https://pipx.pypa.io/latest/installation/) with

```
pipx install lscealice
```
then run it directly from your terminal with

```
lscealice
```

- Or if you don't want to install pipx, you can install it in your python distribution using pip

```
pip install lscealice
```

Then within python run

```
import lscealice
lscealice.launch()
```

## Tutorial

Tutorial and example files are available at [lscealice-tutorial](https://github.com/secretpenguin75/lscealice-tutorial)

Have fun!🐧
